// $Id: dictionarysearchOverlay.js,v 1.5 2004/02/10 21:58:11 jaap Exp $

/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Jaap Haitsma.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * by the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Jaap Haitsma <jaap@haitsma.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// Uncomment DEBUG part and log statements to have logging to the console
// Furthermore you need to add the following two lines to prefs.js to see
// the logging in the shell where you started the browser
// user_pref("browser.dom.window.dump.enabled", true);
// user_pref("javascript.options.showInConsole", true);

////////////////////////////////////////////////////////////////////////////
// Debug part
////////////////////////////////////////////////////////////////////////////
/*
function //log(str){
    dump(str + "\n");
}

function dumpObject(obj){
    dump("\n dumping object contents\n");
    for(i in obj){
        dump(i + " = " + obj[i] + "\n");
    }
    dump("\n");
}
*/
////////////////////////////////////////////////////////////////////////////


// Every time a new browser window is made dictionarySearchInit will be called
window.addEventListener("load",dictionarySearchInit,false);


var dictionarySearchStrBundle;

// This holds the object for accessing the preferences stored in prefs.js
var dictionarySearchPrefs = Components.classes["@mozilla.org/preferences-service;1"].
                            getService(Components.interfaces.nsIPrefService).getBranch("dictionarysearch.");

function dictionarySearchInit() {
    //log("dictionarySearchInit()");

    dictionarySearchStrBundle = document.getElementById("dictionarysearch_string_bundle");
    
    if (!dictionarySearchPrefs.prefHasUserValue("url")){
        //log("dictionarySearchInit(): no preferences found in prefs.js taking defaults");
        // Assign default values
        dictionarySearchPrefs.setCharPref("url", dictionarySearchStrBundle.getString("dictionarysearch.default.URL"));
        dictionarySearchPrefs.setCharPref("menuitem.label", dictionarySearchStrBundle.getString("dictionarysearch.default.menuitem.label"));
        dictionarySearchPrefs.setCharPref("menuitem.accesskey", dictionarySearchStrBundle.getString("dictionarysearch.default.menuitem.accesskey")); 
    }
    try{
        document.getElementById("contentAreaContextMenu").addEventListener("popupshowing",onDictionarySearchPopup,false);  
    }
    catch(e){
       // Do nothing. dictionarySearchInit() is also called when the preferences dia//log is called and there 
       // document.getElementById("contentAreaContextMenu").addEventListener("popupshowing",onDictionarySearchPopup,false);
       // fails
    }
}


function onDictionarySearchPopup() {
    //log("onDictionarySearchPopup()");
    // hide the Dictionary Search item when apropriate (use same //logic as for web search)
    var item = document.getElementById("context_dictionarysearchselect");
    if (gContextMenu.isTextSelected){
        var selectedText = dictionarySearchGetSelectedText(" ");
        if (selectedText.length > 18){
            selectedText = selectedText.substr(0,14) + "...";
        }
        item.hidden = false;
        var label = dictionarySearchPrefs.getCharPref("menuitem.label");
        label = label.split("$");
        label = label[0] + selectedText + label[1];
    
        item.setAttribute("label", label);
        item.setAttribute("accesskey", dictionarySearchPrefs.getCharPref("menuitem.accesskey"));
    }
    else{
        item.hidden = true;
    }
}


function onDictionarySearch(){ 
    var url = dictionarySearchURL = dictionarySearchPrefs.getCharPref("url");
    url = url.split("$");
    url = url[0] + dictionarySearchGetSelectedText("+") + url[1];
    //log("onDictionarySearch() : url = " + url);
    openNewTabWith(url, null, null, true);  
}

function dictionarySearchGetSelectedText(concationationChar){
    //log("dictionarySearchGetSelectedText()");

    var charactersToRemove = "\&()[]{}\",.!?':\;";
    
    var text = gContextMenu.searchSelected();
    text = text.split(" ");

    for (i=0; i<text.length; i++){
        var firstChar=text[i].charAt(0);
        while ((charactersToRemove.indexOf(firstChar) != -1) && (text[i].length!=0)){
            
            text[i]=text[i].substring(1, text[i].length);       
            firstChar=text[i].charAt(0);
        } 

        var lastChar=text[i].charAt(text[i].length - 1);

        while ((charactersToRemove.indexOf(lastChar) != -1) && (text[i].length!=0)){
            text[i]=text[i].substring(0, text[i].length - 1);
            lastChar=text[i].charAt(text[i].length - 1);
        } 
    }
    i=0;

    while (text[i].length==0){
        i++;
        if (i>(text.length-1)){
            return "";
        }
    }

    var cleanedText = text[i];
    i++;
    while (i<text.length){
        cleanedText = cleanedText + concationationChar + text[i];
        i++;
    }

    return cleanedText;
}

function dictionarySearchSaveSettings(){
    //log("dictionarySearchSaveSettings()");

    var url = document.getElementById("dictionarysearch_url").value;
    var label = document.getElementById("dictionarysearch_menuitem_label").value;
    var accessKey = document.getElementById("dictionarysearch_menuitem_accesskey").value;

    if (!dictionarySearchCheckDollarSign(url)){
        alert(dictionarySearchStrBundle.getString("dictionarysearch.URL.error"));
        return false;
    }
       
    if (!dictionarySearchCheckDollarSign(label)){
        alert(dictionarySearchStrBundle.getString("dictionarysearch.menuitem.label.error"));
        return false;
    }

    if (label.indexOf(accessKey) == -1){
        alert(dictionarySearchStrBundle.getString("dictionarysearch.menuitem.accesskey.error"));
        return false;
    }

    dictionarySearchPrefs.setCharPref("url", url);
    dictionarySearchPrefs.setCharPref("menuitem.label", label);
    dictionarySearchPrefs.setCharPref("menuitem.accesskey", accessKey);
    return true;
}

function dictionarySearchLoadSettings(){
    //log("dictionarySearchLoadSettings()");
    document.getElementById("dictionarysearch_url").value = dictionarySearchPrefs.getCharPref("url");
    document.getElementById("dictionarysearch_menuitem_label").value = dictionarySearchPrefs.getCharPref("menuitem.label");
    document.getElementById("dictionarysearch_menuitem_accesskey").value = dictionarySearchPrefs.getCharPref("menuitem.accesskey");
}


function dictionarySearchCheckDollarSign(str){
    //log("dictionarySearchCheckDollarSign(str)");

    ind = str.indexOf('$');
    if (ind == -1){
        return false;
    }
    if (ind != str.lastIndexOf('$')){
        return false;
    }
    return true;
}
